BrotherDevice class

Constructors

BrotherDevice({required BrotherDeviceSource source, required BrotherModel model, required String modelName, String? ipAddress, String? location, String? printerName, String? serialNumber, String? nodeName, String? macAddress, String? bleAdvertiseLocalName})
For iOS must set at least ipAddress or serialNumberor bleAdvertiseLocalName For Android must set at least ipAddress or macAddress or bleAdvertiseLocalName or it should be connected in USB
const
BrotherDevice.fromNetwork(BrotherModel model, String? ipAddress)
BrotherDevice.fromUSBDevice(BrotherModel model)
USB devices doesn't work on iOS

Properties

bleAdvertiseLocalName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
ipAddress → String?
final
location → String?
final
macAddress → String?
final
model → BrotherModel
final
modelName → String
final
name → String
no setter
nodeName → String?
final
printerName → String?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String?
final
source → BrotherDeviceSource
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, String?> json) → BrotherDevice?