BrotherLabelSize enum

Inheritance
Available extensions

Values

QLDieCutW17H54 → const BrotherLabelSize
QLDieCutW17H87 → const BrotherLabelSize
QLDieCutW23H23 → const BrotherLabelSize
QLDieCutW29H42 → const BrotherLabelSize
QLDieCutW29H90 → const BrotherLabelSize
QLDieCutW38H90 → const BrotherLabelSize
QLDieCutW39H48 → const BrotherLabelSize
QLDieCutW52H29 → const BrotherLabelSize
QLDieCutW62H29 → const BrotherLabelSize
QLDieCutW62H100 → const BrotherLabelSize
QLDieCutW60H86 → const BrotherLabelSize
QLDieCutW54H29 → const BrotherLabelSize
QLDieCutW102H51 → const BrotherLabelSize
QLDieCutW102H152 → const BrotherLabelSize
QLDieCutW103H164 → const BrotherLabelSize
QLRollW12 → const BrotherLabelSize
QLRollW29 → const BrotherLabelSize
QLRollW38 → const BrotherLabelSize
QLRollW50 → const BrotherLabelSize
QLRollW54 → const BrotherLabelSize
QLRollW62 → const BrotherLabelSize
QLRollW62RB → const BrotherLabelSize
QLRollW102 → const BrotherLabelSize
QLRollW103 → const BrotherLabelSize
QLDTRollW90 → const BrotherLabelSize
QLDTRollW102 → const BrotherLabelSize
QLDTRollW102H51 → const BrotherLabelSize
QLDTRollW102H152 → const BrotherLabelSize
PT3_5mm → const BrotherLabelSize
PT6mm → const BrotherLabelSize
PT9mm → const BrotherLabelSize
PT12mm → const BrotherLabelSize
PT18mm → const BrotherLabelSize
PT24mm → const BrotherLabelSize
PT36mm → const BrotherLabelSize
PTHS_5_8mm → const BrotherLabelSize
PTHS_8_8mm → const BrotherLabelSize
PTHS_11_7mm → const BrotherLabelSize
PTHS_17_7mm → const BrotherLabelSize
PTHS_23_6mm → const BrotherLabelSize
PTFL_21x45mm → const BrotherLabelSize

Properties

description → String

Available on BrotherLabelSize, provided by the BrotherLabelSizeExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double?

Available on BrotherLabelSize, provided by the BrotherLabelSizeExtension extension

no setter
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double

Available on BrotherLabelSize, provided by the BrotherLabelSizeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toParam() → String

Available on BrotherLabelSize, provided by the BrotherLabelSizeExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BrotherLabelSize>
A constant List of the values in this enum, in order of their declaration.